module Control( RegD, AluSrc, PcSrc, Mem2Reg, AluOp, RegWrite, MemWrite, MemRead, Inst , Zero, clk);


input[31:0]	Inst;
input clk, Zero;

output[2:0]		AluOp;
output[1:0]		RegD, PcSrc, Mem2Reg;
output						AluSrc, RegWrite, MemWrite, MemRead;

reg[2:0]		AluOp;
reg[1:0]		RegD, PcSrc, Mem2Reg;
reg						AluSrc, RegWrite, MemWrite, MemRead;

always @(Inst or Zero or clk)
begin
	
	AluOp = 3'b000;
	{RegD, PcSrc, Mem2Reg}= 6'h00;
	{AluSrc, RegWrite, MemWrite, MemRead} = 4'h0;
	case (Inst[31:26])
		6'h00 : //r-type
				begin
					if(Inst[5:0] == 6'b001000) // jr
						begin
							PcSrc = 2'b10;
						end
					else
						begin
							RegD = 2'b01;
							RegWrite = 1'b1;
							AluOp = (Inst[5:0] == 6'b100000) ? 3'b010 :
											(Inst[5:0] == 6'b100010) ? 3'b110 :
											(Inst[5:0] == 6'b100100) ? 3'b000 :
											(Inst[5:0] == 6'b100101) ? 3'b001 :
											(Inst[5:0] == 6'b101010) ? 3'b111 : 3'b000;
						end
				end
		6'h23 : //lw
				begin
					AluSrc = 1'b1;
					RegWrite = 1'b1;
					MemRead = 1'b1;
					RegWrite = 1'b1;
					AluOp = 3'b010;
					Mem2Reg = 2'b01;
				end
		6'h2b : //sw
				begin
					AluSrc = 1'b1;
					MemWrite = 1'b1;
					AluOp = 3'b010;
				end
		6'h04 : //beq
				begin
					PcSrc =	{1'b0,Zero};
					AluOp = 3'b110;
				end
		6'h02 : //j
				begin
					PcSrc =	2'b11;
				end
		6'h03 : //jal
				begin
					RegD = 2'b10;
					RegWrite = 1'b1;
					PcSrc =	2'b11;
					Mem2Reg = 2'b10;
				end
	endcase
end

initial

begin
	AluOp = 3'b000;
	{RegD, PcSrc, Mem2Reg}= 6'h00;
	{AluSrc, RegWrite, MemWrite, MemRead} = 4'h0;
end

endmodule